# NOTE: This package is fully arched due to dependency sensitivity.
# Please do not remove archfulness on Requires/Provides.

%define debug_package %{nil}

%global min_dnf_ver 2.0.0
%global dnf_incompat_ver 3.0
%global min_pykickstart_ver 2.25

Name:          livecd-tools
Summary:       Tools for building live CDs
Version:       24.2
Release:       3%{?dist}.1
License:       GPLv2
Group:         System/Base
URL:           https://github.com/livecd-tools/livecd-tools
Source0:       https://releases.pagure.org/%{name}/%{name}-%{version}.tar.gz

# Sample minimal Mageia kickstarts based on included Fedora one
Source1:       livecd-mageia-minimal-x86_64.ks
Source2:       livecd-mageia-minimal-i586.ks

# Patches backported from upstream
Patch0001:     0001-Use-genisoimage-instead-of-mkisofs.patch
Patch0002:     0001-Remove-absolute-directories-on-external-program-call.patch

# Mageia specific patches
Patch1001:     1001-livecd-tools-18-dracut_conf.patch
Patch1002:     1002-livecd-tools-18-force-dracut-also-for-initrd.patch
#Patch1003:     1003-livecd-tools-24-squashfs-tools.patch
Patch1004:     1004-livecd-tools-24-extra_filesystems.patch
Patch1005:     1005-livecd-tools-24-disable-efi.patch


BuildRequires: python2-devel
BuildRequires: python3-devel
# pod2man comes from perl
BuildRequires: perl

Requires:      python3-imgcreate%{?_isa} = %{version}-%{release}

%ifarch %{ix86} x86_64
Requires:      livecd-iso-to-mediums = %{version}-%{release}
%endif

%description
Tools for generating live CDs on Fedora based systems including
derived distributions such as RHEL, CentOS and others. See
http://fedoraproject.org/wiki/FedoraLiveCD for more details.

This package is patched to support building live images on
Mageia systems.

%package -n python-imgcreate-sysdeps
Summary:       Common system dependencies for python-imgcreate
Group:         System/Base
Requires:      coreutils
Requires:      cdrkit-genisoimage
Requires:      isomd5sum
Requires:      parted
Requires:      util-linux
Requires:      dosfstools
Requires:      e2fsprogs
# mkefiboot from lorax, disabled by patch1005
#Requires:      lorax >= 18.3
Requires:      rsync
%ifarch %{ix86} x86_64 ppc ppc64
Requires:      hfsplus-tools
%endif
%ifarch %{ix86} x86_64
Requires:      syslinux
%endif
%ifarch ppc
Requires:      yaboot
%endif
Requires:      dumpet
Requires:      sssd-client
Requires:      cryptsetup
Requires:      squashfs-tools
Requires:      policycoreutils

%description -n python-imgcreate-sysdeps
This package describes the common system dependencies for
python-imgcreate.

%package -n python2-imgcreate
Summary:       Python 2 modules for building system images
Group:         Development/Python
Provides:      python-imgcreate%{?_isa} = %{version}-%{release}
Provides:      python-imgcreate = %{version}-%{release}
Obsoletes:     python-imgcreate < 21.2-7
Requires:      python-imgcreate-sysdeps%{?_isa} = %{version}-%{release}
Requires:      python-parted
Requires:      python2-dnf >= %{min_dnf_ver}
Conflicts:     python2-dnf >= %{dnf_incompat_ver}
Requires:      python-kickstart >= %{min_pykickstart_ver}
Requires:      python-six
Requires:      libselinux-python
Requires:      python-dbus

%description -n python2-imgcreate
Python 2 modules that can be used for building images for things
like live image or appliances.


%package -n python3-imgcreate
Summary:       Python 3 modules for building system images
Group:         Development/Python
Requires:      python-imgcreate-sysdeps%{?_isa} = %{version}-%{release}
Requires:      python3-parted
Requires:      python3-dnf >= %{min_dnf_ver}
Conflicts:     python3-dnf >= %{dnf_incompat_ver}
Requires:      python3-kickstart >= %{min_pykickstart_ver}
Requires:      python3-six
Requires:      libselinux-python3
Requires:      python3-dbus

%description -n python3-imgcreate
Python 3 modules that can be used for building images for things
like live image or appliances.


%ifarch %{ix86} x86_64
%package -n livecd-iso-to-mediums
Summary:       Tools for installing ISOs to different mediums
Group:         System/Base
Requires:      python-imgcreate-sysdeps%{?_isa} = %{version}-%{release}
Obsoletes:     livecd-iso-to-disk < 21.2-7
Provides:      livecd-iso-to-disk = %{version}-%{release}
Requires:      extlinux
Requires:      pxelinux


%description -n livecd-iso-to-mediums
Tools for installing Live CD ISOs to different mediums
(e.g. USB sticks, hard drives, PXE boot, etc.)
%endif

%prep
%autosetup -p1

cp %{S:1} config/
cp %{S:2} config/

%build
# Nothing to do


%install
# Install Python 2 stuff
%make_install PYTHON=python2

# Install Python 3 stuff
%make_install PYTHON=python3

# Delete license file from docs, we'll grab it later
rm -rf %{buildroot}%{_datadir}/doc/%{name}/COPYING

%ifnarch %{ix86} x86_64
# livecd-iso-to-mediums doesn't work without syslinux
rm -rfv %{buildroot}%{_bindir}/livecd-iso-to-*
rm -rfv %{buildroot}%{_mandir}/man8/livecd-iso-to-*
%endif

%files
%license COPYING
%doc AUTHORS README HACKING
%doc config/livecd-fedora-minimal.ks
%doc config/livecd-mageia-minimal-*.ks
%{_bindir}/livecd-creator
%{_bindir}/image-creator
%{_bindir}/liveimage-mount
%{_bindir}/edit-livecd
%{_bindir}/mkbiarch
%{_mandir}/man8/livecd-creator.8*
%{_mandir}/man8/mkbiarch.8*


%files -n python-imgcreate-sysdeps
# No files because empty metapackage


%files -n python2-imgcreate
%license COPYING
%doc API
%{python2_sitelib}/imgcreate


%files -n python3-imgcreate
%license COPYING
%doc API
%{python3_sitelib}/imgcreate

%ifarch %{ix86} x86_64
%files -n livecd-iso-to-mediums
%license COPYING
%{_bindir}/livecd-iso-to-disk
%{_mandir}/man8/livecd-iso-to-disk.8*
%{_bindir}/livecd-iso-to-pxeboot
%endif


%changelog
* Wed Mar 29 2017 Neal Gompa <ngompa@mageia.org> 24.2-3.mga6.0.1
- Test patch for GH:livecd-tools/livecd-tools#53

* Wed Mar 08 2017 Neal Gompa <ngompa@mageia.org> 24.2-3.mga6
+ Revision: 1089940
- Remove nonexistent package from sample kickstarts breaking image builds

* Wed Mar 08 2017 Neal Gompa <ngompa@mageia.org> 24.2-2.mga6
+ Revision: 1089936
- Fix typo in livecd-mageia-minimal-i586.ks to make sure it uses i586 repos

* Wed Mar 08 2017 Neal Gompa <ngompa@mageia.org> 24.2-1.mga6
+ Revision: 1089786
- Rebase to official upstream v24.2
- Backport patch from upstream to use genisoimage instead of mkisofs
- Split out and rework patches for adapting livecd-tools to run on Mageia
- Replace example kickstarts with minimal examples

* Sat Feb 20 2016 Sysadmin Bot <umeabot@mageia.org> 21.2-6.mga6
+ Revision: 971805
- Mageia 6 Mass Rebuild

* Tue Oct 20 2015 David GEIGER <daviddavid@mageia.org> 21.2-5.mga6
+ Revision: 892983
- use new python macros to fix build
- add more docs to fix build with latest rpm

* Wed Oct 15 2014 Sysadmin Bot <umeabot@mageia.org> 21.2-4.mga5
+ Revision: 744757
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 Thierry Vignaud <tv@mageia.org> 21.2-3.mga5
+ Revision: 726985
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 Sysadmin Bot <umeabot@mageia.org> 21.2-2.mga5
+ Revision: 681963
- Mageia 5 Mass Rebuild

* Sat Sep 06 2014 Angelo Naselli <anaselli@mageia.org> 21.2-1.mga5
+ Revision: 673012
- new 21.2 from mga branch
- Fixes Bug 10259 - livecd-tools new security issue CVE-2013-2069
+ Sysadmin Bot <umeabot@mageia.org>
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 Sysadmin Bot <umeabot@mageia.org> 17.15-2.mga3
+ Revision: 358885
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 26 2012 Angelo Naselli <anaselli@mageia.org> 17.15-1.mga3
+ Revision: 335521
- Aligned to livecd-tools 17.15
- Fixed bug #06925: livecd-iso-to-disk should require isomd5sum

* Sun Feb 12 2012 Angelo Naselli <anaselli@mageia.org> 14.3-2.mga2
+ Revision: 208261
- reverted apply_patches seems not to work as expected
- kickstart file clean up
- removed mandriva system in description

* Sun Feb 12 2012 Angelo Naselli <anaselli@mageia.org> 14.3-1.mga2
+ Revision: 208232
- Force to use dracut configuration for initrd also
- Moved dracut.conf in /etc/dracut.conf.d/99livecd.conf
- Added hostonly=no into 99livecd.conf
- Now %%post is run as in fedora after boot_config
- imported package livecd-tools
